==> python-gnocchiclient_2.2.0.orig.tar.xz: python-gnocchiclient-2.2.0/gnocchiclient/v1/archive_policy_rule.py <==
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from oslo_serialization import jsonutils

from gnocchiclient.v1 import base


class ArchivePolicyRuleManager(base.Manager):
    url = "v1/archive_policy_rule/"

    def list(self):
        """List archive policy rules

        """
        return self._get(self.url).json()

    def get(self, name):
        """Get an archive policy rules

        :param name: Name of the archive policy rule
        :type name: str
        """
        return self._get(self.url + name).json()

    def create(self, archive_policy_rule):
        """Create an archive policy rule

        """
        return self._post(
            self.url, headers={'Content-Type': "application/json"},
            data=jsonutils.dumps(archive_policy_rule)).json()

    def delete(self, name):
        """Delete an archive policy rule

        :param name: Name of the archive policy rule
        :type name: str
        """
        self._delete(self.url + name)

==> python-gnocchiclient_7.1.0.orig.tar.xz: python-gnocchiclient-7.1.0/gnocchiclient/v1/archive_policy_rule.py <==
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import ujson

from gnocchiclient.v1 import base


class ArchivePolicyRuleManager(base.Manager):

    url = "v1/archive_policy_rule/"

    def list(self):
        """List archive policy rules."""
        return self._get(self.url).json()

    def get(self, name):
        """Get an archive policy rules.

        :param name: Name of the archive policy rule
        :type name: str
        """
        return self._get(self.url + name).json()

    def create(self, archive_policy_rule):
        """Create an archive policy rule."""
        return self._post(
            self.url, headers={'Content-Type': "application/json"},
            data=ujson.dumps(archive_policy_rule)).json()

    def update(self, name, new_name):
        """Update an archive policy rule.

        :param name: the name of archive policy rule
        :type name: str
        :param new_name: the new name of archive policy rule
        :type new_name: str

        """
        return self._patch(
            self.url + '/' + name,
            headers={'Content-Type': "application/json"},
            data=ujson.dumps({'name': new_name})).json()

    def delete(self, name):
        """Delete an archive policy rule.

        :param name: Name of the archive policy rule
        :type name: str
        """
        self._delete(self.url + name)
